==> haskell-dlist-0.8.0.4-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dlist
version: 0.8.0.4
id: dlist-0.8.0.4-1ko0mqe9GjgFHGqItZxWDW
key: dlist-0.8.0.4-1ko0mqe9GjgFHGqItZxWDW
license: BSD-3-Clause
copyright: 2006-2009 Don Stewart, 2013-2016 Sean Leather
maintainer: Sean Leather <sean.leather@gmail.com>
author: Don Stewart
homepage: https://github.com/spl/dlist
synopsis: Difference lists
description:
    Difference lists are a list-like type supporting O(1) append. This is
    particularly useful for efficient logging and pretty printing (e.g. with the
    Writer monad), where list append quickly becomes too expensive.
category: Data
abi: a40d5ba978a5156c7ca110ede78127fd
exposed: True
exposed-modules:
    Data.DList
import-dirs: /usr/lib/ghc-8.4.2/site-local/dlist-0.8.0.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/dlist-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/dlist-0.8.0.4
hs-libraries: HSdlist-0.8.0.4-1ko0mqe9GjgFHGqItZxWDW
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
haddock-interfaces: /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html: /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-0.8.0.4-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dlist
version: 0.8.0.4
id: dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
key: dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
license: BSD-3-Clause
copyright: 2006-2009 Don Stewart, 2013-2016 Sean Leather
maintainer: Sean Leather <sean.leather@gmail.com>
author: Don Stewart
homepage: https://github.com/spl/dlist
synopsis: Difference lists
description:
    Difference lists are a list-like type supporting O(1) append. This is
    particularly useful for efficient logging and pretty printing (e.g. with the
    Writer monad), where list append quickly becomes too expensive.
category: Data
abi: d8185cdeb1f72c3606ef0c9fb78dc6d0
exposed: True
exposed-modules:
    Data.DList
import-dirs: /usr/lib/ghc-8.4.3/site-local/dlist-0.8.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/dlist-0.8.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/dlist-0.8.0.4
hs-libraries: HSdlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html: /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
